@@ -1,3 +1,4 @@
+import sys
 from ...yarn import yarn_adapter
 from ..base import BaseYarnCommand
 from argparse import REMAINDER
@@ -14,9 +15,10 @@ class Command(BaseYarnCommand):
         super(Command, self).handle(*args, **options)
         args = args or tuple(options.pop('command'))
         if self._is_single_command('install', args):
-            self._install([])
+            ret = self._install([])
         else:
-            yarn_adapter.call_yarn(args)
+            ret = yarn_adapter.call_yarn(args)
+        sys.exit(ret)
 
     def _is_single_command(self, name, args):
         return len(args) == 1 and args[0] == name
