@@ -24,8 +24,8 @@ class BaseYarnCase(TestCase):
     def tearDown(self):
         self._remove_node_modules_root()
 
-    def _remove_components_root(self):
-        """Remove components root if exists"""
+    def _remove_node_modules_root(self):
+        """Remove node_modules root if exists"""
         if os.path.exists(TEST_NODE_MODULES_ROOT):
             shutil.rmtree(TEST_NODE_MODULES_ROOT)
 
